Installation
============

Installing the application
--------------------------

From the command line:

.. code-block:: bash

   pip install papermill

Installing In-Notebook bindings
-------------------------------

* `Python`_ (No additional installation required since Python bindings are built
  into **papermill**. See section on *In-Notebook bindings*)
* `R`_ (available in the **papermillr** project)

.. _`Python`: https://github.com/nteract/papermill/blob/master/README.md
.. _`R`: https://github.com/nteract/papermillr
